import QtQuick 2.0
import Sailfish.Silica 1.0
import org.nemomobile.configuration 1.0

Page {
    id: page

    ConfigurationGroup {
        id: analogclockSettings
        path: "/jolla-clock/analogclock"
		property bool analogClock: true
		property bool analogClockSeconds: false
		property bool digitalclockSeconds: false
        property int size: 320
		property int clocktopmargin: 130
		property int datetopmargin: 6
        property int face: 1	
        property int hourhandle: 1	
	    property int minutehandle: 1
		property int secondshandle: 1
		property bool digitalclock: false
        property int dclocksize: 100
        property int dclocktopmargin: 130
		property int weathertopmargin: 480
        property bool landscape: false
        property bool background: false
        property int opacity: 50
        property bool weather: false
        property int lockScale: 80
		property int sneakScale: 90		
        property int weekdaysize: 30
        property int shortdatesize: 50	
		property bool alarmIndicators: false
		property bool colored_alarmIndicators: false
		property bool forecast: false
		property bool launch_clock: false
		property bool launch_calendar: false
		property bool launch_digital_clock: false
		property int weather_app: 0
		property bool launch_weather: false
    }

    SilicaFlickable {
        anchors.fill: parent
        contentHeight: content.height
        interactive: contentHeight > height
		
        PullDownMenu {
            MenuItem {
                text: qsTr("Settings for landscape orientation")
                onClicked: pageStack.push(Qt.resolvedUrl("landscape.qml"))
            }
        }
		
        Column {
		    id: content
            width: parent.width
            spacing: Theme.paddingLarge
			
			SectionHeader {
		        text: qsTr("Settings for portrait orientation")
		    }	
   		
			ExpandingSection {
                buttonHeight: Theme.itemSizeMedium
                title: qsTr("Analog clock")
				
                content.sourceComponent: Column {
				
				TextSwitch {
					width: parent.width
					text: qsTr("Show analog clock")
					checked: analogclockSettings.analogClock
					onClicked: analogclockSettings.analogClock = checked
				}
					
	                width: parent.width
					
				    SectionHeader {
		                text: qsTr("Choose clock face")
						visible: analogclockSettings.analogClock
		            }
								
		            ListView {
		                id: clockfaceRow
		                width: parent.width
						height: width/4
						visible: analogclockSettings.analogClock
						orientation: ListView.Horizontal
                        focus: true
						highlightFollowsCurrentItem: true
						highlight: Rectangle { color: Theme.secondaryHighlightColor }
						Component.onCompleted: currentIndex = analogclockSettings.face - 1
                        highlightMoveDuration: 10
						delegate:
                        Image {
                            source: modelData
						    height: clockfaceRow.width/4
							width: height
						    MouseArea {
                                anchors.fill: parent
                                onClicked: { clockfaceRow.currentIndex = index
		                        analogclockSettings.face = index + 1
	     		                }
                            }
                        }							
					}
					
                    Component.onCompleted: {
                        var faces = [
                            "analog_clock_face_1.svg",
                            "analog_clock_face_2.svg",
                            "analog_clock_face_3.svg",
                            "analog_clock_face_4.svg"
                        ]
                        clockfaceRow.model = faces
						var hourhandles = [
                            "analog_hour_handle_1.svg",
                            "analog_hour_handle_2.svg",
                            "analog_hour_handle_3.svg",
                            "analog_hour_handle_4.svg"
                        ]
                        hourhandleRow.model = hourhandles
						var minutehandles = [
                            "analog_minute_handle_1.svg",
                            "analog_minute_handle_2.svg",
                            "analog_minute_handle_3.svg",
                            "analog_minute_handle_4.svg"
                        ]
                        minutehandleRow.model = minutehandles
						var secondhandles = [
                            "analog_second_handle_1.svg",
                            "analog_second_handle_2.svg"
                        ]
                        secondshandleRow.model = secondhandles						
                    }						
					
		            Separator {
		                color: Theme.secondaryHighlightColor
		                width: parent.width
		                anchors.horizontalCenter: parent.horizontalCenter
		                horizontalAlignment: Qt.AlignHCenter
						visible: analogclockSettings.analogClock
		            }
					
				    SectionHeader {
		                text: qsTr("Choose hour handle")
						visible: analogclockSettings.analogClock
		            }
					
		            ListView {
		                id: hourhandleRow
		                width: parent.width
						height: width/4
						visible: analogclockSettings.analogClock
						orientation: ListView.Horizontal
                        focus: true
						highlightFollowsCurrentItem: true
						highlight: Rectangle { color: Theme.secondaryHighlightColor }
						Component.onCompleted: currentIndex = analogclockSettings.hourhandle - 1
                        highlightMoveDuration: 10
						delegate:
                        Image {
                            source: modelData
						    height: hourhandleRow.width/4
							width: height
						    MouseArea {
                                anchors.fill: parent
                                onClicked: { hourhandleRow.currentIndex = index
		                        analogclockSettings.hourhandle = index + 1
	     		                }
                            }
                        }							
					}			
					
		            Separator {
		                color: Theme.secondaryHighlightColor
		                width: parent.width
		                anchors.horizontalCenter: parent.horizontalCenter
		                horizontalAlignment: Qt.AlignHCenter
						visible: analogclockSettings.analogClock
		            }
					
				    SectionHeader {
		                text: qsTr("Choose minute handle")
						visible: analogclockSettings.analogClock
		            }
					
		            ListView {
		                id: minutehandleRow
		                width: parent.width
						height: width/4
						visible: analogclockSettings.analogClock
						orientation: ListView.Horizontal
                        focus: true
						highlightFollowsCurrentItem: true
						highlight: Rectangle { color: Theme.secondaryHighlightColor }
						Component.onCompleted: currentIndex = analogclockSettings.minutehandle - 1
                        highlightMoveDuration: 10
						delegate:
                        Image {
                            source: modelData
						    height: hourhandleRow.width/4
							width: height
						    MouseArea {
                                anchors.fill: parent
                                onClicked: { minutehandleRow.currentIndex = index
		                        analogclockSettings.minutehandle = index + 1
	     		                }
                            }
                        }							
					}
										
		            Separator {
		                color: Theme.secondaryHighlightColor
		                width: parent.width
		                anchors.horizontalCenter: parent.horizontalCenter
		                horizontalAlignment: Qt.AlignHCenter
						visible: analogclockSettings.analogClock
		            }
					
					TextSwitch {
						width: parent.width
						visible: analogclockSettings.analogClock
						text: qsTr("Enable seconds")
						checked: analogclockSettings.analogClockSeconds
						onClicked: analogclockSettings.analogClockSeconds = checked
					}	
										
				    SectionHeader {
		                text: qsTr("Choose seconds handle")
						visible: analogclockSettings.analogClockSeconds && analogclockSettings.analogClock
		            }
					
		            ListView {
		                id: secondshandleRow
		                width: parent.width
						height: width/2
						visible: analogclockSettings.analogClockSeconds && analogclockSettings.analogClock
						orientation: ListView.Horizontal
                        focus: true
						highlightFollowsCurrentItem: true
						highlight: Rectangle { color: Theme.secondaryHighlightColor }
						Component.onCompleted: currentIndex = analogclockSettings.secondshandle - 1
                        highlightMoveDuration: 10
						delegate:
                        Image {
                            source: modelData
						    height: secondshandleRow.width/2
							width: height
						    MouseArea {
                                anchors.fill: parent
                                onClicked: { secondshandleRow.currentIndex = index
		                        analogclockSettings.secondshandle = index + 1
	     		                }
                            }
                        }							
					}
										
		            Separator {
		                color: Theme.secondaryHighlightColor
		                width: parent.width
		                anchors.horizontalCenter: parent.horizontalCenter
		                horizontalAlignment: Qt.AlignHCenter
						visible: analogclockSettings.analogClock
		            }	
					
		            TextSwitch {
						width: parent.width
						visible: analogclockSettings.analogClock
		                text: qsTr("Enable background")
						description: qsTr("Enables colored background. Probably it will be useful with light-ambiences.")
		                checked: analogclockSettings.background
		                onClicked: analogclockSettings.background = checked
		            }
		
					Slider { 			   
		                width: parent.width
						visible: analogclockSettings.background && analogclockSettings.analogClock
		                label: qsTr("Opacity")
		                maximumValue: 90
		                minimumValue: 10
		                stepSize: 1
		                value: analogclockSettings.opacity
		                valueText: value + "%"
		
		                onValueChanged: analogclockSettings.opacity = Math.round(value)
		                onPressAndHold: cancel()
		            }
					
		            TextSwitch {
		                width: parent.width
		                text: qsTr("Enable alarm indicators")
		                checked: analogclockSettings.alarmIndicators
		                onClicked: analogclockSettings.alarmIndicators = checked
		            }
					
		            TextSwitch {
						visible: analogclockSettings.alarmIndicators
						description: qsTr("Enables different colors for alarm indicators like in Clock-app cover.")
		                width: parent.width
		                text: qsTr("Use colored indicators")
		                checked: analogclockSettings.colored_alarmIndicators
		                onClicked: analogclockSettings.colored_alarmIndicators = checked
		            }	
					
		            Separator {
		                color: Theme.secondaryHighlightColor
		                width: parent.width
		                anchors.horizontalCenter: parent.horizontalCenter
		                horizontalAlignment: Qt.AlignHCenter
						visible: analogclockSettings.analogClock
		            }
					
		            TextSwitch {
						description: qsTr("Enables clock launching by clicking on clock-face from lockscreen.")
						visible: analogclockSettings.analogClock
		                width: parent.width
		                text: qsTr("Enable clock-launch from lockscreen")
		                checked: analogclockSettings.launch_clock
		                onClicked: analogclockSettings.launch_clock = checked
		            }						
				}
            }
			
			ExpandingSection {
                buttonHeight: Theme.itemSizeMedium
                title: qsTr("Digital clock")
				
                content.sourceComponent: Column {
	                width: parent.width	
					
		            TextSwitch {
		                width: parent.width
		                text: qsTr("Show digital clock")
		                checked: analogclockSettings.digitalclock
		                onClicked: analogclockSettings.digitalclock = checked
		            }
										
		            TextSwitch {
		                width: parent.width
						visible: analogclockSettings.digitalclock
		                text: qsTr("Enable seconds")
		                checked: analogclockSettings.digitalclockSeconds
		                onClicked: analogclockSettings.digitalclockSeconds = checked
		            }
					
			        TextSwitch {
						description: qsTr("Enables clock launching by clicking on clock from lockscreen.")
						visible: analogclockSettings.digitalclock
		                width: parent.width
		                text: qsTr("Enable clock-launch from lockscreen")
		                checked: analogclockSettings.launch_digital_clock
		                onClicked: analogclockSettings.launch_digital_clock = checked
		            }				
				}
			}
			
			ExpandingSection {
                buttonHeight: Theme.itemSizeMedium
                title: qsTr("Lockscreen date")
				
                content.sourceComponent: Column {
	                width: parent.width	
										
		            TextSwitch {
						description: qsTr("Enables calendar launching by clicking on the date from lockscreen.")
		                width: parent.width
		                text: qsTr("Enable calendar-launch from lockscreen")
		                checked: analogclockSettings.launch_calendar
		                onClicked: analogclockSettings.launch_calendar = checked
		            }				
				}
			}	
			
			ExpandingSection {
                buttonHeight: Theme.itemSizeMedium
                title: qsTr("Weather-widget")
				
                content.sourceComponent: Column {
	                width: parent.width	
					
		            TextSwitch {
		                width: parent.width
		                text: qsTr("Show weather-widget")
		                checked: analogclockSettings.weather
		                onClicked: analogclockSettings.weather = checked
		            }
					
					ComboBox {
						width: parent.width
						visible: analogclockSettings.weather
						label: qsTr("Choose weather application")
						currentIndex: updateIndex(analogclockSettings.weather_app)

						menu: ContextMenu {
							MenuItem {
								text: qsTr("Jolla-weather*")
								onClicked: {
									analogclockSettings.weather_app = 0
								}
							}
							
							MenuItem {
								text: "MeeCast*"
								onClicked: {
									analogclockSettings.weather_app = 1
								}
							}
						}

						function updateIndex(value) {
							if (value == 0) {
								return 0
							} else if (value == 1) {
								return 1
							}
						}
					}
					
		            Label {
					    visible: analogclockSettings.weather
                        text: analogclockSettings.weather_app === 0 ? "* " + qsTr("Requires installed Jolla-weather application.") : "* " + qsTr("Requires installed MeeCast and MeeCast Eventsview applications.")
                        width: parent.width
						font.pixelSize: Theme.pixelSizeSmall
				        wrapMode: Text.Wrap
                        horizontalAlignment: Text.AlignLeft
                    }	
					
		            Slider {
		                width: parent.width
						visible: analogclockSettings.weather
		                label: qsTr("Choose lockscreen widget scale")
		                maximumValue: Screen.sizeCategory < Screen.Large ? 150 : 200
		                minimumValue: 50
		                stepSize: 10
		                value: analogclockSettings.lockScale
		                valueText: value + "%"
		
		                onValueChanged: analogclockSettings.lockScale = Math.round(value)
		                onPressAndHold: cancel()
		            }
					
		            Slider {
		                width: parent.width
						visible: analogclockSettings.weather
		                label: qsTr("Choose Sneak Peek widget scale")
		                maximumValue: Screen.sizeCategory < Screen.Large ? 150 : 200
		                minimumValue: 50
		                stepSize: 10
		                value: analogclockSettings.sneakScale
		                valueText: value + "%"
		
		                onValueChanged: analogclockSettings.sneakScale = Math.round(value)
		                onPressAndHold: cancel()
		            }	
					
		            TextSwitch {
		                width: parent.width
						visible: analogclockSettings.weather
		                text: qsTr("Enable weather-app launch from lockscreen")
						description: qsTr("Enables weather-app launching by long tap on weather-widget from lockscreen.")
		                checked: analogclockSettings.launch_weather
		                onClicked: analogclockSettings.launch_weather = checked
		            }	
					
		            TextSwitch {
		                width: parent.width
						visible: analogclockSettings.weather
		                text: qsTr("Enable 5-days forecast")
						description: qsTr("It will show 5-day weather forecast on your lockscreen, click weather-widget to show or hide forecast.") + " " +
							qsTr("Please, hide forecast before disabling this option.")
		                checked: analogclockSettings.forecast
		                onClicked: analogclockSettings.forecast = checked
		            }					
				}	
			}
			
			ExpandingSection {
                buttonHeight: Theme.itemSizeMedium
                title: qsTr("Clocks and date sizes")
				
                content.sourceComponent: Column {
	                width: parent.width			
			
		            Slider {
		                width: parent.width
		                label: qsTr("Analog clock size")
						visible: analogclockSettings.analogClock
		                maximumValue: Screen.sizeCategory < Screen.Large ? 560 : 1000
		                minimumValue: 200
		                stepSize: 10
		                value: analogclockSettings.size
		                valueText: value + "x" + value + " " + qsTr("px")
		
		                onValueChanged: analogclockSettings.size = Math.round(value)
		                onPressAndHold: cancel()
		            }
					
		            Slider {
		                width: parent.width
						visible: analogclockSettings.digitalclock
		                label: qsTr("Digital clock size")
		                maximumValue: 220
		                minimumValue: 10
		                stepSize: 1
		                value: analogclockSettings.dclocksize
		                valueText: value + " " + qsTr("px")
		
		                onValueChanged: analogclockSettings.dclocksize = Math.round(value)
		                onPressAndHold: cancel()
		            }
					
		            Slider {
		                width: parent.width
		                label: qsTr("Weekday size")
		                maximumValue: Screen.sizeCategory < Screen.Large ? 120 : 200
		                minimumValue: 10
		                stepSize: 1
		                value: analogclockSettings.weekdaysize
		                valueText: value + " " + qsTr("px")
		
		                onValueChanged: analogclockSettings.weekdaysize = Math.round(value)
		                onPressAndHold: cancel()
		            }
					
		            Slider {
		                width: parent.width
		                label: qsTr("Month date size")
		                maximumValue: Screen.sizeCategory < Screen.Large ? 120 : 200
		                minimumValue: 10
		                stepSize: 1
		                value: analogclockSettings.shortdatesize
		                valueText: value + " " + qsTr("px")
		
		                onValueChanged: analogclockSettings.shortdatesize = Math.round(value)
		                onPressAndHold: cancel()
		            }
				}
			}	
						
			ExpandingSection {
                buttonHeight: Theme.itemSizeMedium
                title: qsTr("Margins")
				id: margins
                content.sourceComponent: Column {
	                width: parent.width
					
					Slider {
		                width: parent.width
		                label: qsTr("Analog clock top margin")
						enabled: margins.expanded
		                maximumValue: 800
		                minimumValue: Screen.sizeCategory < Screen.Large ? 0 : -800
		                stepSize: 1
		                value: analogclockSettings.clocktopmargin
		                valueText: value
						visible: analogclockSettings.analogClock
		                onValueChanged: analogclockSettings.clocktopmargin = Math.round(value)
		                onPressAndHold: cancel()
		            }
					
					Slider {
		                width: parent.width
						visible: analogclockSettings.digitalclock
						enabled: margins.expanded
		                label: qsTr("Digital clock top margin")
		                maximumValue: 900
		                minimumValue: Screen.sizeCategory < Screen.Large ? 10 : -800
		                stepSize: 1
		                value: analogclockSettings.dclocktopmargin
		                valueText: value
		
		                onValueChanged: analogclockSettings.dclocktopmargin = Math.round(value)
		                onPressAndHold: cancel()
		            }
					
					Slider {
		                width: parent.width
		                label: qsTr("Date top margin")
						enabled: margins.expanded
		                maximumValue: 800
		                minimumValue: Screen.sizeCategory < Screen.Large ? -100 : -800
		                stepSize: 1
		                value: analogclockSettings.datetopmargin
		                valueText: value
		
		                onValueChanged: analogclockSettings.datetopmargin = Math.round(value)
		                onPressAndHold: cancel()
		            }
					
					Slider {
		                width: parent.width
		                label: qsTr("Weather-widget top margin")
						enabled: margins.expanded
		                maximumValue: 800
		                minimumValue: Screen.sizeCategory < Screen.Large ? -100 : -800
		                stepSize: 1
		                value: analogclockSettings.weathertopmargin
		                valueText: value
						visible: analogclockSettings.weathertopmargin		
		                onValueChanged: analogclockSettings.weathertopmargin = Math.round(value)
		                onPressAndHold: cancel()
		            }					
				}
			}	
									
		    Item {
			    width: 1
                height: Theme.paddingMedium
			}	
			
            Separator {
                color: Theme.secondaryHighlightColor
                width: parent.width
                anchors.horizontalCenter: parent.horizontalCenter
                horizontalAlignment: Qt.AlignHCenter
            }
			
		    Item {
			    width: 1
                height: Theme.paddingMedium
			}
			
            Label {
                width: parent.width
                wrapMode: Text.Wrap
                horizontalAlignment: Text.AlignHCenter
                text: qsTr("Created by Ancelad in 0x7DF")
            }
			
		    Item {
			    width: 1
                height: Theme.paddingMedium
			}	
			
            Label {
                width: parent.width
                wrapMode: Text.Wrap
                horizontalAlignment: Text.AlignHCenter
                text: qsTr("Big thanks to Ruslan Burkhanov for \nSVG-graphics :)")
            }
			
		    Item {
			    width: 1
                height: Theme.paddingMedium
			}	
			
		    Label {
                text: qsTr("Donations are welcome :)")
                width: parent.width
				wrapMode: Text.Wrap
                horizontalAlignment: Text.AlignHCenter
            }

			Item {			    
			    width: 1
				height: Theme.paddingLarge
			}
            
			Row {
                anchors.horizontalCenter: parent.horizontalCenter
                spacing: Theme.paddingLarge*4
                
                IconButton {
                    icon.source: "paypal.svg"
                    icon.height: Theme.itemSizeMedium
                    icon.width: Theme.itemSizeMedium
                    onClicked: {
                        Qt.openUrlExternally("https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=E33PBZ79WTQJY")
                    }
                }
                
                IconButton {
                    id: sbrf
                    icon.source: "sbrf.svg"
                    icon.height: Theme.itemSizeMedium
                    icon.width: Theme.itemSizeMedium
                }                
			}
 
			Item {			    
			    width: 1
				height: Theme.paddingLarge
			}
 
            Label {
                anchors.horizontalCenter: parent.horizontalCenter
                visible: sbrf.pressed
                text: "4276 1600 2051 7877"
                font.pixelSize: Theme.fontSizeLarge
            }
            
			Item {			    
			    width: 1
				height: Theme.paddingLarge*4
			}   			
        }
    }
}
